@@ -9,6 +9,7 @@ def _enable_logging(f):
 
     import logging
     import functools
+    import os
 
     @functools.wraps(f)
     def decorator(*args, **kwargs):
@@ -19,9 +20,9 @@ def _enable_logging(f):
         except ModuleNotFoundError:
             return f(*args, **kwargs)
 
-        # Enable logging
+        # Enable logging in development mode
         disabled = logging.getLogger("cs50").disabled
-        if flask.current_app:
+        if flask.current_app and os.getenv("FLASK_ENV") == "development":
             logging.getLogger("cs50").disabled = False
         try:
             return f(*args, **kwargs)
@@ -382,9 +383,9 @@ class SQL(object):
                 elif command in ["DELETE", "UPDATE"]:
                     ret = result.rowcount
 
-            # If constraint violated, return None
+            # If constraint violated
             except sqlalchemy.exc.IntegrityError as e:
-                self._logger.debug(termcolor.colored(statement, "yellow"))
+                self._logger.error(termcolor.colored(_statement, "red"))
                 e = ValueError(e.orig)
                 e.__cause__ = None
                 raise e
@@ -392,14 +393,14 @@ class SQL(object):
             # If user error
             except (sqlalchemy.exc.OperationalError, sqlalchemy.exc.ProgrammingError) as e:
                 self._disconnect()
-                self._logger.debug(termcolor.colored(statement, "red"))
+                self._logger.error(termcolor.colored(_statement, "red"))
                 e = RuntimeError(e.orig)
                 e.__cause__ = None
                 raise e
 
             # Return value
             else:
-                self._logger.debug(termcolor.colored(_statement, "green"))
+                self._logger.info(termcolor.colored(_statement, "green"))
                 if self._autocommit:  # Don't stay connected unnecessarily
                     self._disconnect()
                 return ret
